Module accept

Module accept 

Structs

AuthReuseCache
Authentication policy for inbound connections. Bounded compatibility authentication state keyed by source IP.
InboundShadowsocksConfig
Configuration for Shadowsocks inbound listener.
InboundTrojanConfig
Configuration for Trojan inbound listener.
PendingHttpForward
A pending HTTP forward-proxy request.
PendingTunnel
A pending tunnel connection (HTTP CONNECT, SOCKS4, SOCKS5). Success reply has NOT been sent yet.
PendingUdpAssociate
A pending SOCKS5 UDP ASSOCIATE session.

Enums

AcceptError
Error type for accept operations.
AcceptedSession
The result of accepting an inbound connection.
InboundAuthentication
ReplyContext
Information needed to send a protocol-specific reply later.
TunnelProtocol
Which tunnel protocol was used.

Functions

accept
Read the first byte from the stream, detect the protocol, perform the handshake parsing, and return an AcceptedSession without opening any outbound connection or sending any success/failure reply.
accept_with_fixed_target
accept_with_fixed_target_for_peer