Functions
- send_
http_ expectation_ failed - Reject request expectations because the forwarder does not implement the 100-continue negotiation or a concurrent request/response pump.
- send_
http_ forward_ failure - Send an HTTP forward-proxy failure reply.
- send_
http_ upgrade_ unsupported - Reject an upstream protocol upgrade rather than accidentally turning the forward-proxy session into an unframed tunnel.
- send_
tunnel_ failure - Send a tunnel failure reply when route opening fails.
- send_
tunnel_ success - Send a tunnel success reply after route is established.