AuthReuseCache

Struct AuthReuseCache 

pub struct AuthReuseCache { /* private fields */ }
Authentication policy for inbound connections. Bounded compatibility authentication state keyed by source IP.

This intentionally lives in the server crate but is only constructed by the pproxy compatibility runtime. Native Eggress listeners continue to authenticate every connection independently.

Implementations

Source

impl AuthReuseCache

pub const DEFAULT_MAX_ENTRIES: usize = 4096

pub fn new(timeout: Duration) -> Self

pub fn lookup(&self, peer_ip: IpAddr) -> Option<ClientIdentity>

pub fn record(&self, peer_ip: IpAddr, identity: ClientIdentity)

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool