Module reply

Module reply 

Functions

send_http_expectation_failed
Reject request expectations because the forwarder does not implement the 100-continue negotiation or a concurrent request/response pump.
send_http_forward_failure
Send an HTTP forward-proxy failure reply.
send_http_upgrade_unsupported
Reject an upstream protocol upgrade rather than accidentally turning the forward-proxy session into an unframed tunnel.
send_tunnel_failure
Send a tunnel failure reply when route opening fails.
send_tunnel_success
Send a tunnel success reply after route is established.